@@ -10,6 +10,7 @@ our @EXPORT = qw(
     get_xpath
     test_xml_attribute_ok
     test_xml_value_ok
+    get_single_node_ok
     net_saml2_sp
     looks_like_a_cert
     net_saml2_binding_redirect_request
@@ -33,26 +34,24 @@ use URI::URL;
 
 sub net_saml2_sp {
     return Net::SAML2::SP->new(
-        id               => 'http://localhost:3000',
-        url              => 'http://localhost:3000',
-        cert             => 't/sign-nopw-cert.pem',
-        key              => 't/sign-nopw-cert.pem',
-        cacert           => 't/cacert.pem',
-        org_name         => 'Test',
-        org_display_name => 'Test',
+
+
+        id     => 'Some entity ID',
+        cert   => 't/sign-nopw-cert.pem',
+        key    => 't/sign-nopw-cert.pem',
+        cacert => 't/cacert.pem',
+
+        org_name         => 'Net::SAML2::SP',
+        org_display_name => 'Net::SAML2::SP testsuite',
         org_contact      => 'test@example.com',
         org_url          => 'http://www.example.com',
-        slo_url_soap     => '/slo-soap',
+
+        url              => 'http://localhost:3000',
         slo_url_redirect => '/sls-redirect-response',
-        slo_url_post     => '/sls-post-response',
         acs_url_post     => '/consumer-post',
         acs_url_artifact => '/consumer-artifact',
-        org_name         => 'Net::SAML2 Saml2Test',
-        org_display_name => 'Saml2Test app for Net::SAML2',
-        org_contact      => 'saml2test@example.com',
         error_url        => '/error',
-        authnreq_signed  => '0',
-        want_assertions_signed => '0',
+
         @_,
     );
 }
@@ -78,7 +77,6 @@ sub net_saml2_binding_redirect_request {
 
     my $metadata_xml = path('t/net-saml2-idp-metadata.xml')->slurp;
     my $cacert       = 't/net-saml2-cacert.pem';
-    my $cert_file    = 't/net-saml2-cert.pem';
     my $sp_acs_url   = 'http://ct.local/saml/consumer-post';
 
     my $nameid  = 'timlegge@cpan.org';
@@ -94,11 +92,9 @@ sub net_saml2_binding_redirect_request {
         cacert => $cacert,          # Filename of the Identity Providers CACert
     );
 
-    my $sp_signing_cert = path($cert_file)->slurp;
-
     my $redirect = Net::SAML2::Binding::Redirect->new(
         key => '',
-        cert => $sp_signing_cert,
+        cert => $idp->certs->{signing},
         param => 'SAMLRequest',
         # The ssl_url destination for redirect
         url => $idp->sso_url('urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect'),
@@ -216,6 +212,14 @@ sub get_xpath {
     return $xp;
 }
 
+sub get_single_node_ok {
+    my $xpc = shift;
+    my $xpath = shift;
+    my $nodes = $xpc->findnodes($xpath);
+    is($nodes->size, 1, "Got 1 node for $xpath");
+    return $nodes->get_node(1);
+}
+
 sub test_xml_attribute_ok {
     my ($xpath, $search, $value) = @_;
 
